@@ -1,4 +1,4 @@
-// Copyright (c) 2021 Ivan Jelincic <parazyd@dyne.org>
+// Copyright (c) 2021 Streamflow Labs Limited <legal@streamflowlabs.com>
 //
 // This file is part of streamflow-finance/timelock-crate
 //
@@ -17,9 +17,9 @@
 //! The code providing timelock primitives
 //! used by [streamflow.finance](https://streamflow.finance).
 
-/// Functions related to SPL tokens
-pub mod associated_token;
 /// Structs and data
 pub mod state;
+/// Functions related to SPL tokens
+pub mod token;
 /// Utility functions
 pub mod utils;
